# Lesezeichen
Lesezeichen 'lzn' organizes your bookmarks on the shell - fast, shell completion


# Code completion

Install code completion Example for zsh and oh my zsh:
```
_LZN_COMPLETE=zsh_source lzn > .oh-my-zsh/completions/lzn.zsh
```
